This is a useful module.Its full name called 'mymodule'.But someone upload on pypi a module called 'mymodule' back in 2012,so,you know, the last thing I want to do is to abbreviate this module name into mmodule.But use it,dude.It can draw polygon instantly,it can conversion from one time units to the other time units,etc.It's 2021 now.Take care of yourself in this pandemic.Live it!